MatchText:

`
MatchText
::= begin end text polarity conceptAttributes
`

no references

begin:

`
begin ::= 'first physician note character position'
`

referenced by:

- MatchText

end:

`
end ::= 'last physician note character position'
`

referenced by:

- MatchText

text:

`
text ::= 'Hepatocellcular Carcinoma'
`

referenced by:

- MatchText

polarity:

`
polarity ::= Positive 'example: patient has liver cancer'
| Negated 'no evidence of liver cancer'
`

referenced by:

- MatchText

conceptAttributes:

`
conceptAttributes
::= UmlsConcept+
`

referenced by:

- MatchText

UmlsConcept:

`
UmlsConcept
::= tui cui codingScheme code
`

referenced by:

- conceptAttributes

tui:

`
tui ::= 'UMLS Term Unique Identifier (TUI)'
`

referenced by:

- UmlsConcept

cui:

`
cui ::= 'UMLS Concept Unique Identifier(CUI) across all vocabularies'
`

referenced by:

- UmlsConcept

codingScheme:

`
codingScheme
::= 'vocabulary source'
`

referenced by:

- UmlsConcept

code:

`
code ::= 'identifier in vocabulary source'
`

referenced by:

- UmlsConcept

| ... generated by RR - Railroad Diagram Generator |